summaryrefslogtreecommitdiff
path: root/src/leap/bitmask/cli
diff options
context:
space:
mode:
authorRuben Pollan <meskio@sindominio.net>2017-12-08 12:35:30 +0100
committerKali Kaneko <kali@leap.se>2017-12-20 15:27:02 +0100
commitd5bd7394344afd2c6466f368a0de7566094a0d0d (patch)
treef821f1e8f384a60d75a125a116566103143a8e10 /src/leap/bitmask/cli
parent8c50952bb542a09ebe591d9dba3b4d89d4837b54 (diff)
[refactor] rename API add_msg to msg_add
To have consistency with all API calls related to messages and start all of them with msg_*
Diffstat (limited to 'src/leap/bitmask/cli')
-rw-r--r--src/leap/bitmask/cli/mail.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/leap/bitmask/cli/mail.py b/src/leap/bitmask/cli/mail.py
index 0e8b6584..bb880e7b 100644
--- a/src/leap/bitmask/cli/mail.py
+++ b/src/leap/bitmask/cli/mail.py
@@ -35,7 +35,7 @@ SUBCOMMANDS:
disable Stop service
status Display status about service
get_token Returns token for the mail service
add_msg Add a msg file to a mailbox
'''.format(name=command.appname)
@@ -75,7 +75,7 @@ SUBCOMMANDS:
return self._send(command.default_printer)
- def add_msg(self, raw_args):
+ def msg_add(self, raw_args):
parser = argparse.ArgumentParser(
description='Bitmask email status',
prog='%s %s %s' % tuple(sys.argv[:3]))
@@ -99,7 +99,7 @@ SUBCOMMANDS:
with open(subargs.file[0], 'r') as msgfile:
rawmsg = msgfile.read()
- self.data += ['add_msg', userid, mailbox, rawmsg]
+ self.data += ['msg_add', userid, mailbox, rawmsg]
return self._send(command.default_printer)
@@ -35,7 +35,7 @@ SUBCOMMANDS:
status Display status about service
get_token Returns token for the mail service
- add_msg Add a msg file to a mailbox
+ msg_add Add a msg file to a mailbox
'''.format(name=command.appname)